%define pypi_name borgbackup
%define _exclude_files_from_autoprov %{python2_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so


Name:           borgbackup
Version:        1.2.2
Release:        %mkrel 1
Group:          Archiving/Backup
Summary:        Deduplicated backups

License:        BSD
URL:            https://borgbackup.github.io/
Source0:        https://pypi.io/packages/source/b/%{pypi_name}/%{pypi_name}-%{version}.tar.xz
Patch0:         0001-Remove-codecov.io-and-travis-ci.org-badges.patch
Patch1:         0002-README.rst-Replace-img-src-with-text-link.patch
Patch3:         0003-disable-sphinx-man-page-build.patch
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-setuptools
BuildRequires:  python3-msgpack
BuildRequires:  pkgconfig(openssl)
BuildRequires:  libacl-devel
BuildRequires:  python3-cython
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  python3-llfuse
BuildRequires:  python3-setuptools_scm
BuildRequires: python3-tomli
Requires: python3-msgpack

%description
BorgBackup (short: Borg) is a deduplicating backup program.
Optionally, it supports compression and authenticated encryption.

The main goal of Borg is to provide an efficient and secure way to backup data.
The data deduplication technique used makes Borg suitable for daily backups
since only changes are stored. The authenticated encryption technique makes
it suitable for backups to not fully trusted targets.


%prep
%setup -q -n %{pypi_name}-%{version}
%apply_patches

# remove .c files so cython rebuild them
rm -f {borg/crypto.c,borg/platform_linux.c}


%build
%py3_build

# MANPAGE GENERATION
# workaround to dump sphinx_rtd_theme dependency - not needed for manpages
export READTHEDOCS=True

# workaround to include borg module for usage generation
export PYTHONPATH=$(pwd)/build/$(ls build/ | grep 'lib.')

#make -C docs SPHINXBUILD=sphinx-build-3 man


%install
%py3_install

#install -D -m 0644 docs/_build/man/borg*.1* %{buildroot}%{_mandir}/man1/borg.1

# add shell completions
%define bash_compdir %{_prefix}/share/bash-completion/completions
%define zsh_compdir %{_prefix}/share/zsh/site-functions

install -d  %{buildroot}%{bash_compdir}
install -d  %{buildroot}%{zsh_compdir}

install -D -m 0644 scripts/shell_completions/bash/* %{buildroot}%{bash_compdir}
install -D -m 0644 scripts/shell_completions/zsh/* %{buildroot}%{zsh_compdir}


%files
%doc LICENSE
%doc README.rst PKG-INFO AUTHORS
%doc docs/changes.rst
%{python3_sitearch}
%{_bindir}/borg
%{_bindir}/borgfs
%{_prefix}/share/bash-completion/completions/*
%{_prefix}/share/zsh/site-functions/*



%changelog
* Mon Aug 29 2022 tex - 1.2.2-1pclos2022
- new version

* Tue Dec 24 2019 tex - 1.1.10-1pclos2020
- new version

* Wed Apr 24 2019 tex - 1.1.9-1pclos2019
- new

* Wed Mar 20 2019 tex - 1.1.8-2pclos2019
- rebuild against updates
- req python3-msgpack

* Tue Mar 19 2019 tex 1.1.8-1pclos2019
- new
